@@ -3,6 +3,7 @@ package MooTester2;
 use Moo;
 
 use MooX::JSON_LD 'Example';
+use JSON::MaybeXS;
 
 use namespace::autoclean;
 
@@ -25,4 +26,9 @@ has boop => (
     json_ld => 1,
 );
 
+around _build_json_ld_encoder => sub {
+    return JSON->new->utf8->canonical;
+};
+
+
 1;
